==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_af.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Volledig</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Beperking met 'n as...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>definieer 'n bewegingsbeperking tussen twee voorwerpe met 'n as</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Selftoets...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Loop 'n selftoets om na te gaan dat die toepassing ordentlik werk</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Dr&amp;awing</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;ketch</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Straalsporing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Teken</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Sketsgebaseerd</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitives</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametries</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Voorwerpvoorkoms</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Draadwerktuie</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_af.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="af" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Volledig</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Beperking met 'n as...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>definieer 'n bewegingsbeperking tussen twee voorwerpe met 'n as</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Selftoets...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Loop 'n selftoets om na te gaan dat die toepassing ordentlik werk</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Dr&amp;awing</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;ketch</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Straalsporing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Teken</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Sketsgebaseerd</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitives</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametries</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Voorwerpvoorkoms</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Draadwerktuie</translation>
    </message>
  </context>
</TS>
